@@ -336,7 +336,7 @@ constructOverlayLayoutChildClipOverlay val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data OverlayLayoutChildClipOverlayPropertyInfo
 instance AttrInfo OverlayLayoutChildClipOverlayPropertyInfo where
-    type AttrAllowedOps OverlayLayoutChildClipOverlayPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps OverlayLayoutChildClipOverlayPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint OverlayLayoutChildClipOverlayPropertyInfo = IsOverlayLayoutChild
     type AttrSetTypeConstraint OverlayLayoutChildClipOverlayPropertyInfo = (~) Bool
     type AttrTransferTypeConstraint OverlayLayoutChildClipOverlayPropertyInfo = (~) Bool
@@ -346,6 +346,7 @@ instance AttrInfo OverlayLayoutChildClipOverlayPropertyInfo where
     type AttrOrigin OverlayLayoutChildClipOverlayPropertyInfo = OverlayLayoutChild
     attrGet = getOverlayLayoutChildClipOverlay
     attrSet = setOverlayLayoutChildClipOverlay
+    attrPut = setOverlayLayoutChildClipOverlay
     attrTransfer _ v = do
         return v
     attrConstruct = constructOverlayLayoutChildClipOverlay
@@ -388,7 +389,7 @@ constructOverlayLayoutChildMeasure val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data OverlayLayoutChildMeasurePropertyInfo
 instance AttrInfo OverlayLayoutChildMeasurePropertyInfo where
-    type AttrAllowedOps OverlayLayoutChildMeasurePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps OverlayLayoutChildMeasurePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint OverlayLayoutChildMeasurePropertyInfo = IsOverlayLayoutChild
     type AttrSetTypeConstraint OverlayLayoutChildMeasurePropertyInfo = (~) Bool
     type AttrTransferTypeConstraint OverlayLayoutChildMeasurePropertyInfo = (~) Bool
@@ -398,6 +399,7 @@ instance AttrInfo OverlayLayoutChildMeasurePropertyInfo where
     type AttrOrigin OverlayLayoutChildMeasurePropertyInfo = OverlayLayoutChild
     attrGet = getOverlayLayoutChildMeasure
     attrSet = setOverlayLayoutChildMeasure
+    attrPut = setOverlayLayoutChildMeasure
     attrTransfer _ v = do
         return v
     attrConstruct = constructOverlayLayoutChildMeasure
